/*
 * Copyright 2001 OpenPrivacy.org.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the LICENSE which you should have obtaind with this package. 
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.
 */

package talon.interfaces;

import java.io.*;
import java.net.*;
import java.util.*;
import talon.*;
import talon.Component;
import talon.components.*;
import talon.interfaces.*;
import talon.util.net.*;

/**
 * Class that supports basic assertions.  JDK 1.4 has support for this but since
 * it is so simple this class provides ubiquity.
 *
 * @author <a href="mailto:burton@relativity.yi.org">Kevin A. Burton</a>
 * @version $Id: Assertable.java,v 1.1 2001/06/08 08:02:55 burton Exp $
 */
public interface Assertable {

    /**
     * @see #assert
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Assertable.java,v 1.1 2001/06/08 08:02:55 burton Exp $
     */
    public void assert( boolean expression, String message ) throws RuntimeException;

    /**
     * Check to make sure the given object is not null.  Basically assert that
     * it has a value.  This is essentially a shortcut for:
     * 
     * assert( object != null, "The given object is null" )
     *
     * @see #assert
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Assertable.java,v 1.1 2001/06/08 08:02:55 burton Exp $
     */
    public void assert( Object object ) throws RuntimeException;

    /**
     * Make sure the given object has a value and provide the given message if
     * it is.
     *
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Assertable.java,v 1.1 2001/06/08 08:02:55 burton Exp $
     */
    public void assert( Object object, String message ) throws RuntimeException;
    
    /**
     * Assert that the given expression is false.  If it is true then we should
     * assume something bad has happened.
     *
     * Example:
     *
     * <code>
     *
     *  assert( somethingBad() != true )
     *
     * </code>
     *
     * If the value of 'exception' is true then we should throw an Exception.
     *
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Assertable.java,v 1.1 2001/06/08 08:02:55 burton Exp $
     */
    public void assert( boolean expression, String message, boolean exception );

}
