/*
 * Copyright 2001 OpenPrivacy.org.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the LICENSE which you should have obtaind with this package. 
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.
 */

package talon.resources;

import java.io.*;
import java.net.*;
import java.util.*;

import talon.*;
import talon.interfaces.*;
import talon.util.net.*;

/**
 * <p>
 * A resource maps a URL in a transparent manner.
 *
 * @author <a href="mailto:burton@relativity.yi.org">Kevin A. Burton</a>
 * @version $Id: Resource.java,v 1.2 2001/12/02 05:37:48 burton Exp $
 */
public interface Resource {
    
    /**
     * Get a URL to this resource.
     *
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Resource.java,v 1.2 2001/12/02 05:37:48 burton Exp $
     */
    public URL getURL();

    /**
     * Get an OutputStream to this URL so that you can update it at runtime.
     *
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Resource.java,v 1.2 2001/12/02 05:37:48 burton Exp $
     */
    public OutputStream getOutputStream() throws IOException;

    /**
     * Get the full path for this resource as a file on the local filesystem.
     * Return null if this Resource doesn't support this type of mapping.
     *
     * @author <a href="mailto:burton@openprivacy.org">Kevin A. Burton</a>
     */
    public String getPathTranslated();
    
}

