/*
 * Copyright 2001 OpenPrivacy.org.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the LICENSE which you should have obtaind with this package. 
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.
 */

package talon.util;

import java.util.*;

import talon.*;
import talon.components.*;
import talon.util.net.*;

/**
 * Provides a wrapper around the Talon logger so that you can call the default
 * Logger without instance from a static class.
 *
 * Should support the following log levels
 * <pre>
 * 
 * debug 
 * info
 * error
 * warn
 * fatal
 *
 * </pre>
 * 
 * Also each level should support the following options:
 *
 * <pre>
 * 
 * message (required)
 * category (optional)
 * throwable (optional)
 * 
 * </pre>
 *
 * @author <a href="mailto:burton@relativity.yi.org">Kevin A. Burton</a>
 * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
 */
public class Log {

    private static Logger logger = ComponentFactory.getLogger();

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void message( String message ) {
        logger.message( message );
    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void message( String message, Object category ) {
        logger.message( message, category );
    }
    
    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void debug( String message ) {
        logger.debug( message );
    }
    
    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void debug( String message, Object category ) {
        logger.debug( message, category );
    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void warn( String message ) {
        logger.warn( message );
    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void warn( String message, Object category ) {
        logger.warn( message, category );
    }
    
    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void error( Throwable throwable ) {

        String message = "null";
        
        if ( throwable != null ) 
            message = throwable.getMessage();
        
        logger.error( message, throwable );
        
    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void error( String message ) {
        
        logger.error( message );

    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void error( Object category,
                              Throwable throwable ) {

        logger.error( throwable.getMessage(), category, throwable );

    }
    
    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static void error( String message,
                              Object category,
                              Throwable throwable ) {

        logger.error( message, category, throwable );

    }

    /**
     * @see Logger
     * @author <a href="mailto:burton@relativity.yi.org">burtonator</a>
     * @version $Id: Log.java,v 1.8 2002/03/09 23:01:48 burton Exp $
     */
    public static Logger getLogger( final Object object ) {

        return logger.getLogger( object );
        
    }
    
}

